//
//  MainView.h
//  Impressionist
//
//  Created by Stephanie Abascal on 1/24/09.
//  Copyright Stephanie Abascal 2009. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <vector>

typedef enum StrokeType	{
	BRUSH_POINT = 0,
	BRUSH_LINE,
	BRUSH_CIRCLE,
	BRUSH_SCATTERED_POINTS,
	BRUSH_SCATTERED_LINES,
	BRUSH_SCATTERED_CIRCLES
};

typedef enum AngleType {
	ANGLE_SLIDER = 0,
	ANGLE_MOVEMENT,
	ANGLE_GRADIENT
};

struct Stroke {
	StrokeType type;
	CGPoint location;
	float alpha;
	float angle;
	float size;
	
	Stroke() { }
	Stroke(StrokeType t, CGPoint l, float alpha_) : type(t), location(l), alpha(alpha_) { }
};

@interface MainView : UIView {
	std::vector<Stroke> strokes;
	
	unsigned char *rawData;
	unsigned char *x_grad, *y_grad;
	StrokeType brush;
	AngleType angleType;
	
	unsigned imgWidth;
	unsigned imgHeight;
	unsigned bytesPerRow;
	unsigned bytesPerPixel;
	unsigned clearImage;
	
	double* custom_kernel;
	double kernel_divisor, kernel_offset;
	
	double angle, opacity, size, thickness;

	CGImageRef cached;
}

- (void)applyKernel:(double*)values divisor:(double)d offset:(double)o;
- (void)setImage:(UIImage*)paintImage;
- (void)clearImage;
- (void)computeGradient;

@property StrokeType brush;
@property AngleType angleType;
@property double angle;
@property double opacity;
@property double size;
@property double thickness;

@end
